package com.zehong.system.mapper;

import java.util.List;
import com.zehong.system.domain.TCar;

/**
 * 巡检车Mapper接口
 * 
 * @author zehong
 * @date 2026-05-15
 */
public interface TCarMapper 
{
    /**
     * 查询巡检车
     * 
     * @param id 巡检车ID
     * @return 巡检车
     */
    public TCar selectTCarById(Long id);

    /**
     * 查询巡检车列表
     * 
     * @param tCar 巡检车
     * @return 巡检车集合
     */
    public List<TCar> selectTCarList(TCar tCar);

    /**
     * 新增巡检车
     * 
     * @param tCar 巡检车
     * @return 结果
     */
    public int insertTCar(TCar tCar);

    /**
     * 修改巡检车
     * 
     * @param tCar 巡检车
     * @return 结果
     */
    public int updateTCar(TCar tCar);

    /**
     * 删除巡检车
     * 
     * @param id 巡检车ID
     * @return 结果
     */
    public int deleteTCarById(Long id);

    /**
     * 批量删除巡检车
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTCarByIds(Long[] ids);
}
